# Features

This section presents in details the different features of Outlines.

## Core Concepts

- [Models](./models/index.md)
- [Model Inputs](./core/inputs.md)
- [Output Types](./core/output_types.md)
- [Generators](./core/generator.md)

## Utilities

- [Applications](./utility/application.md)
- [Templates](./utility/templates.md)
- [Regex DSL](./utility/regex_dsl.md)

## Advanced

- [Logits Processors](./advanced/logits_processors.md)
